@@ -11,30 +11,30 @@ that is how the resulting directory will be named.
 In practice, you should use either actual clean tags from a current build or
 something like 'current' as a stable URL for the mest current version of the """
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Imports
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 import os
 import re
 import shutil
 import sys
 from os import chdir as cd
-from os.path import join as pjoin
 
 from subprocess import Popen, PIPE, CalledProcessError, check_call
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Globals
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 pages_dir = 'gh-pages'
 html_dir = 'build/html'
 pdf_dir = 'build/latex'
-pages_repo = 'git@github.com:scikit-image/docs.git'
+pages_repo = 'https://github.com/scikit-image/docs.git'
 
-#-----------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
 # Functions
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 def sh(cmd):
     """Execute command in a subshell, return status code."""
     return check_call(cmd, shell=True)
@@ -48,7 +48,7 @@ def sh2(cmd):
     out = p.communicate()[0]
     retcode = p.returncode
     if retcode:
-        print out.rstrip()
+        print(out.rstrip())
         raise CalledProcessError(retcode, cmd)
     else:
         return out.rstrip()
@@ -69,26 +69,31 @@ def sh3(cmd):
 
 def init_repo(path):
     """clone the gh-pages repo if we haven't already."""
-    sh("git clone %s %s"%(pages_repo, path))
+    sh(f'git clone --branch gh-pages {pages_repo} {path} --depth 1')
     here = os.getcwd()
     cd(path)
     sh('git checkout gh-pages')
     cd(here)
 
-#-----------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
 # Script starts
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 if __name__ == '__main__':
-    # find the version number from setup.py
-    setup_lines = open('../setup.py').readlines()
+    # find the version number from skimage/__init__.py
+    setup_lines = open('../skimage/__init__.py').readlines()
     tag = 'vUndefined'
     for l in setup_lines:
-        if l.startswith('VERSION'):
+        if l.startswith('__version__'):
             tag = l.split("'")[1]
-            break
 
-    if "dev" in tag:
-        tag = "dev"
+            if "dev" in tag:
+                tag = "dev"
+            else:
+                # Rename e.g. 0.9.0 to 0.9.x
+                tag = '.'.join(tag.split('.')[:-1] + ['x'])
+
+            break
 
     startdir = os.getcwd()
     if not os.path.exists(pages_dir):
@@ -107,28 +112,32 @@ if __name__ == '__main__':
     shutil.rmtree(dest, ignore_errors=True)
     shutil.copytree(html_dir, dest)
     # copy pdf file into tree
-    #shutil.copy(pjoin(pdf_dir, 'scikits.image.pdf'), pjoin(dest, 'scikits.image.pdf'))
+    # shutil.copy(pjoin(pdf_dir, 'scikits.image.pdf'), pjoin(dest, 'scikits.image.pdf'))
 
     try:
         cd(pages_dir)
         status = sh2('git status | head -1')
-        branch = re.match('\# On branch (.*)$', status).group(1)
-        if branch != 'gh-pages':
-            e = 'On %r, git branch is %r, MUST be "gh-pages"' % (pages_dir,
-                                                                 branch)
+        branch = re.match(b'On branch (.*)$', status).group(1)
+        if branch != b'gh-pages':
+            e = f'On {pages_dir!r}, git branch is {branch!r}, MUST be "gh-pages"'
             raise RuntimeError(e)
         sh("touch .nojekyll")
         sh('git add .nojekyll')
         sh('git add index.html')
-        sh('git add %s' % tag)
-        sh2('git commit -m"Updated doc release: %s"' % tag)
+        sh(f'git add --all {tag}')
 
-        print 'Most recent commit:'
+        status = sh2('git status | tail -1')
+        if not re.match(b'nothing to commit', status):
+            sh2(f'git commit -m"Updated doc release: {tag}"')
+        else:
+            print('\n! Note: no changes to commit\n')
+
+        print('Most recent commit:')
         sys.stdout.flush()
         sh('git --no-pager log --oneline HEAD~1..')
     finally:
         cd(startdir)
 
-    print
-    print 'Now verify the build in: %r' % dest
-    print "If everything looks good, run 'git push' inside doc/gh-pages."
+    print('')
+    print(f'Now verify the build in: {dest!r}')
+    print("If everything looks good, run 'git push' inside doc/gh-pages.")
